@@ -23,17 +23,11 @@ __all__ = [
     "AnyFilter",
     "AnyUnitTest",
     "DynamicStringField",
-    "DynamicStringFieldOverrides",
     "DynamicDestinations",
-    "DynamicDestinationsOverrides",
     "AlertGrouping",
-    "AlertGroupingOverrides",
     "PythonFilter",
-    "PythonFilterOverrides",
     "UnitTestMock",
-    "UnitTestMockOverrides",
     "JSONUnitTest",
-    "JSONUnitTestOverrides",
     "Policy",
     "PolicyOverrides",
     "Rule",
@@ -67,12 +61,6 @@ def overridable(cls: typing.Callable) -> typing.Callable:
         *args: typing.Any,
         overrides: typing.Optional[
             typing.Union[
-                "DynamicStringFieldOverrides",
-                "DynamicDestinationsOverrides",
-                "AlertGroupingOverrides",
-                "PythonFilterOverrides",
-                "UnitTestMockOverrides",
-                "JSONUnitTestOverrides",
                 "PolicyOverrides",
                 "RuleOverrides",
                 "ScheduledRuleOverrides",
@@ -89,19 +77,6 @@ def overridable(cls: typing.Callable) -> typing.Callable:
     return wrapper
 
 
-@dataclasses.dataclass
-class DynamicStringFieldOverrides:
-    """Overrides dataclass for DynamicStringField. All arguments are marked optional.
-
-    - fallback -- Fallback value in case the dynamic handler fails
-    - func -- Dynamic handler
-    """
-
-    fallback: typing.Optional[str] = None
-
-    func: typing.Optional[typing.Callable[[PantherEvent], str]] = None
-
-
 @dataclasses.dataclass(frozen=True)
 class DynamicStringField(_utilities.SDKNode):
     """Make a field dynamic based on the detection input
@@ -127,19 +102,6 @@ class DynamicStringField(_utilities.SDKNode):
         return ["fallback", "func"]
 
 
-@dataclasses.dataclass
-class DynamicDestinationsOverrides:
-    """Overrides dataclass for DynamicDestinations. All arguments are marked optional.
-
-    - func -- Dynamic handler
-    - fallback -- Fallback value in case the dynamic handler fails
-    """
-
-    func: typing.Optional[typing.Callable[[PantherEvent], typing.List[str]]] = None
-
-    fallback: typing.Optional[typing.List[str]] = None
-
-
 @dataclasses.dataclass(frozen=True)
 class DynamicDestinations(_utilities.SDKNode):
     """Make destinations dynamic based on the detection input
@@ -165,19 +127,6 @@ class DynamicDestinations(_utilities.SDKNode):
         return ["func", "fallback"]
 
 
-@dataclasses.dataclass
-class AlertGroupingOverrides:
-    """Overrides dataclass for AlertGrouping. All arguments are marked optional.
-
-    - group_by -- Function to generate a key for grouping matches
-    - period_minutes -- How long should matches be grouped into an alert after the first match
-    """
-
-    group_by: typing.Optional[typing.Callable[[PantherEvent], str]] = None
-
-    period_minutes: typing.Optional[int] = None
-
-
 @dataclasses.dataclass(frozen=True)
 class AlertGrouping(_utilities.SDKNode):
     """Configuration for how an alert is grouped
@@ -203,16 +152,6 @@ class AlertGrouping(_utilities.SDKNode):
         return ["group_by", "period_minutes"]
 
 
-@dataclasses.dataclass
-class PythonFilterOverrides:
-    """Overrides dataclass for PythonFilter. All arguments are marked optional.
-
-    - func -- Provide a function whose python source will be used as the filter definition
-    """
-
-    func: typing.Optional[typing.Callable[[PantherEvent], bool]] = None
-
-
 @dataclasses.dataclass(frozen=True)
 class PythonFilter(_utilities.SDKNode):
     """Create a filter by referencing a python function
@@ -234,19 +173,6 @@ class PythonFilter(_utilities.SDKNode):
         return ["func"]
 
 
-@dataclasses.dataclass
-class UnitTestMockOverrides:
-    """Overrides dataclass for UnitTestMock. All arguments are marked optional.
-
-    - name -- name of the object to mock
-    - return_value -- string to assign as the return value for the mock
-    """
-
-    name: typing.Optional[str] = None
-
-    return_value: typing.Optional[str] = None
-
-
 @dataclasses.dataclass(frozen=True)
 class UnitTestMock(_utilities.SDKNode):
     """Mock for a unit test
@@ -272,25 +198,6 @@ class UnitTestMock(_utilities.SDKNode):
         return ["name", "return_value"]
 
 
-@dataclasses.dataclass
-class JSONUnitTestOverrides:
-    """Overrides dataclass for JSONUnitTest. All arguments are marked optional.
-
-    - data -- json string
-    - expect_match -- whether the data should match and trigger an alert
-    - name -- name of the unit test
-    - mocks -- list of mocks to use in the test
-    """
-
-    data: typing.Optional[str] = None
-
-    expect_match: typing.Optional[bool] = None
-
-    name: typing.Optional[str] = None
-
-    mocks: typing.Optional[typing.List[UnitTestMock]] = None
-
-
 @dataclasses.dataclass(frozen=True)
 class JSONUnitTest(_utilities.SDKNode):
     """Unit test with json content
@@ -480,7 +387,7 @@ class Policy(_utilities.SDKNode):
     ] = None
 
     # overrides field is used to allow mypy type checking but is not used in Policy functionality
-    overrides: PolicyOverrides = dataclasses.field(
+    overrides: typing.Optional[PolicyOverrides] = dataclasses.field(
         default=PolicyOverrides(), repr=False
     )
 
@@ -676,7 +583,9 @@ class Rule(_utilities.SDKNode):
     ] = None
 
     # overrides field is used to allow mypy type checking but is not used in Rule functionality
-    overrides: RuleOverrides = dataclasses.field(default=RuleOverrides(), repr=False)
+    overrides: typing.Optional[RuleOverrides] = dataclasses.field(
+        default=RuleOverrides(), repr=False
+    )
 
     # internal private methods
     def _typename(self) -> str:
@@ -871,7 +780,7 @@ class ScheduledRule(_utilities.SDKNode):
     ] = None
 
     # overrides field is used to allow mypy type checking but is not used in ScheduledRule functionality
-    overrides: ScheduledRuleOverrides = dataclasses.field(
+    overrides: typing.Optional[ScheduledRuleOverrides] = dataclasses.field(
         default=ScheduledRuleOverrides(), repr=False
     )
 
